EXPORTS
	??0RLbsTestChannel@@QAE@XZ @ 1 NONAME ; RLbsTestChannel::RLbsTestChannel(void)
	??0RLbsTestChannelMsgFifo@@QAE@H@Z @ 2 NONAME ; RLbsTestChannelMsgFifo::RLbsTestChannelMsgFifo(int)
	??0TLbsPrivFwCtrlCloseDownMsg@@QAE@XZ @ 3 NONAME ; TLbsPrivFwCtrlCloseDownMsg::TLbsPrivFwCtrlCloseDownMsg(void)
	??0TLbsPrivFwNotifyRequestMsg@@QAE@AAI@Z @ 4 NONAME ; TLbsPrivFwNotifyRequestMsg::TLbsPrivFwNotifyRequestMsg(unsigned int &)
	??0TLbsPrivFwNotifyResponseMsg@@QAE@AAI@Z @ 5 NONAME ; TLbsPrivFwNotifyResponseMsg::TLbsPrivFwNotifyResponseMsg(unsigned int &)
	??0TLbsPrivFwSessionCompleteMsg@@QAE@AAI@Z @ 6 NONAME ; TLbsPrivFwSessionCompleteMsg::TLbsPrivFwSessionCompleteMsg(unsigned int &)
	??0TLbsPrivFwVerifyRequestMsg@@QAE@AAI@Z @ 7 NONAME ; TLbsPrivFwVerifyRequestMsg::TLbsPrivFwVerifyRequestMsg(unsigned int &)
	??0TLbsPrivFwVerifyResponseMsg@@QAE@AAI@Z @ 8 NONAME ; TLbsPrivFwVerifyResponseMsg::TLbsPrivFwVerifyResponseMsg(unsigned int &)
	??0TLbsTestChannelMsgBase@@QAE@ABV0@@Z @ 9 NONAME ; TLbsTestChannelMsgBase::TLbsTestChannelMsgBase(class TLbsTestChannelMsgBase const &)
	??0TLbsTestChannelMsgBase@@QAE@XZ @ 10 NONAME ; TLbsTestChannelMsgBase::TLbsTestChannelMsgBase(void)
	??0TLbsTestRequestInfo@@QAE@XZ @ 11 NONAME ; TLbsTestRequestInfo::TLbsTestRequestInfo(void)
	??4TLbsTestChannelMsgBase@@QAEAAV0@ABV0@@Z @ 12 NONAME ; class TLbsTestChannelMsgBase & TLbsTestChannelMsgBase::operator=(class TLbsTestChannelMsgBase const &)
	?CancelSendMessageNotification@RLbsTestChannel@@QAEXXZ @ 13 NONAME ; void RLbsTestChannel::CancelSendMessageNotification(void)
	?Close@RLbsTestChannel@@QAEXXZ @ 14 NONAME ; void RLbsTestChannel::Close(void)
	?Close@RLbsTestChannelMsgFifo@@QAEXXZ @ 15 NONAME ; void RLbsTestChannelMsgFifo::Close(void)
	?FindAndRemove@RLbsTestChannelMsgFifo@@QAEHW4TLbsTestChannelMsgType@TLbsTestChannelMsgBase@@@Z @ 16 NONAME ; int RLbsTestChannelMsgFifo::FindAndRemove(enum TLbsTestChannelMsgBase::TLbsTestChannelMsgType)
	?InitializeL@RLbsTestChannel@@SAXW4TLbsTestChannelId@1@@Z @ 17 NONAME ; void RLbsTestChannel::InitializeL(enum RLbsTestChannel::TLbsTestChannelId)
	?IsEmpty@RLbsTestChannelMsgFifo@@QAEHXZ @ 18 NONAME ; int RLbsTestChannelMsgFifo::IsEmpty(void)
	?NewL@CTestRequestChannel@@SAPAV1@PAVMLbsTestChannelRequestObserver@@W4TLbsTestChannelId@RLbsTestChannel@@@Z @ 19 NONAME ; class CTestRequestChannel * CTestRequestChannel::NewL(class MLbsTestChannelRequestObserver *, enum RLbsTestChannel::TLbsTestChannelId)
	?NotificationReason@TLbsTestRequestInfo@@QBE?AW4TPosNotificationReason@@XZ @ 20 NONAME ; enum TPosNotificationReason TLbsTestRequestInfo::NotificationReason(void) const
	?NotificationType@TLbsTestRequestInfo@@QBE?AW4TNotificationType@MLbsPrivacyObserver@@XZ @ 21 NONAME ; enum MLbsPrivacyObserver::TNotificationType TLbsTestRequestInfo::NotificationType(void) const
	?OpenL@RLbsTestChannel@@QAEXW4TLbsTestChannelId@1@AAVMLbsTestChannelObserver@@@Z @ 22 NONAME ; void RLbsTestChannel::OpenL(enum RLbsTestChannel::TLbsTestChannelId, class MLbsTestChannelObserver &)
	?OpenL@RLbsTestChannelMsgFifo@@QAEXXZ @ 23 NONAME ; void RLbsTestChannelMsgFifo::OpenL(void)
	?ProcessTestChannelMessage@CTestRequestChannel@@UAEXW4TLbsTestChannelId@RLbsTestChannel@@ABVTLbsTestChannelMsgBase@@@Z @ 24 NONAME ; void CTestRequestChannel::ProcessTestChannelMessage(enum RLbsTestChannel::TLbsTestChannelId, class TLbsTestChannelMsgBase const &)
	?Read@RLbsTestChannelMsgFifo@@QAEABVTLbsTestChannelMsgBase@@XZ @ 25 NONAME ; class TLbsTestChannelMsgBase const & RLbsTestChannelMsgFifo::Read(void)
	?RequestDecision@TLbsTestRequestInfo@@QBE?AW4TPosRequestDecision@@XZ @ 26 NONAME ; enum TPosRequestDecision TLbsTestRequestInfo::RequestDecision(void) const
	?RequestId@TLbsTestChannelMsgBase@@QBEIXZ @ 27 NONAME ; unsigned int TLbsTestChannelMsgBase::RequestId(void) const
	?RequestSource@TLbsTestRequestInfo@@QBE?AW4TPosRequestSource@@XZ @ 28 NONAME ; enum TPosRequestSource TLbsTestRequestInfo::RequestSource(void) const
	?SendMessage@RLbsTestChannel@@QAEXABVTLbsTestChannelMsgBase@@AAVTRequestStatus@@@Z @ 29 NONAME ; void RLbsTestChannel::SendMessage(class TLbsTestChannelMsgBase const &, class TRequestStatus &)
	?SendPrivFwRequestMessage@CTestRequestChannel@@QAEXABVTLbsTestChannelMsgBase@@@Z @ 30 NONAME ; void CTestRequestChannel::SendPrivFwRequestMessage(class TLbsTestChannelMsgBase const &)
	?ShutDownL@RLbsTestChannel@@SAXW4TLbsTestChannelId@1@@Z @ 31 NONAME ; void RLbsTestChannel::ShutDownL(enum RLbsTestChannel::TLbsTestChannelId)
	?Size@TLbsTestChannelMsgBase@@QBEJXZ @ 32 NONAME ; long TLbsTestChannelMsgBase::Size(void) const
	?TimeoutStrategy@TLbsTestRequestInfo@@QBE?AW4TPosRequestDecision@@XZ @ 33 NONAME ; enum TPosRequestDecision TLbsTestRequestInfo::TimeoutStrategy(void) const
	?Type@TLbsTestChannelMsgBase@@QBE?AW4TLbsTestChannelMsgType@1@XZ @ 34 NONAME ; enum TLbsTestChannelMsgBase::TLbsTestChannelMsgType TLbsTestChannelMsgBase::Type(void) const
	?VerifyCancelReason@TLbsTestRequestInfo@@QBE?AW4TPosVerifyCancelReason@@XZ @ 35 NONAME ; enum TPosVerifyCancelReason TLbsTestRequestInfo::VerifyCancelReason(void) const
	?Write@RLbsTestChannelMsgFifo@@QAEXABVTLbsTestChannelMsgBase@@@Z @ 36 NONAME ; void RLbsTestChannelMsgFifo::Write(class TLbsTestChannelMsgBase const &)
	?SetNotificationReason@TLbsTestRequestInfo@@QAEXW4TPosNotificationReason@@@Z @ 37 NONAME ; void TLbsTestRequestInfo::SetNotificationReason(enum TPosNotificationReason)
	?SetNotificationType@TLbsTestRequestInfo@@QAEXW4TNotificationType@MLbsPrivacyObserver@@@Z @ 38 NONAME ; void TLbsTestRequestInfo::SetNotificationType(enum MLbsPrivacyObserver::TNotificationType)
	?SetRequestDecision@TLbsTestRequestInfo@@QAEXW4TPosRequestDecision@@@Z @ 39 NONAME ; void TLbsTestRequestInfo::SetRequestDecision(enum TPosRequestDecision)
	?SetRequestSource@TLbsTestRequestInfo@@QAEXW4TPosRequestSource@@@Z @ 40 NONAME ; void TLbsTestRequestInfo::SetRequestSource(enum TPosRequestSource)
	?SetTimeoutStrategy@TLbsTestRequestInfo@@QAEXW4TPosRequestDecision@@@Z @ 41 NONAME ; void TLbsTestRequestInfo::SetTimeoutStrategy(enum TPosRequestDecision)
	?SetVerifyCancelReason@TLbsTestRequestInfo@@QAEXW4TPosVerifyCancelReason@@@Z @ 42 NONAME ; void TLbsTestRequestInfo::SetVerifyCancelReason(enum TPosVerifyCancelReason)

